@@ -1,8 +1,8 @@
 <?php
 /**
- * $Header: /repository/pear/Log/Log/display.php,v 1.6 2004/11/27 21:46:50 jon Exp $
+ * $Header$
  *
- * @version $Revision: 1.6 $
+ * @version $Revision$
  * @package Log
  */
 
@@ -22,19 +22,29 @@
 class Log_display extends Log
 {
     /**
-     * String to output before an error message
+     * String containing the format of a log line.
      * @var string
      * @access private
      */
-    var $_error_prepend = '';
+    var $_lineFormat = '<b>%3$s</b>: %4$s';
 
     /**
-     * String to output after an error message
+     * String containing the timestamp format.  It will be passed directly to
+     * strftime().  Note that the timestamp string will generated using the
+     * current locale.
      * @var string
      * @access private
      */
-    var $_error_append = '';
+    var $_timeFormat = '%b %d %H:%M:%S';
 
+    /**
+     * Flag indicating whether raw message text should be passed directly to 
+     * the log system.  Otherwise, the text will be converted to an HTML-safe 
+     * representation.
+     * @var boolean
+     * @access private
+     */
+    var $_rawText = false;
 
     /**
      * Constructs a new Log_display object.
@@ -52,17 +62,75 @@ class Log_display extends Log
         $this->_ident = $ident;
         $this->_mask = Log::UPTO($level);
 
-        if (!empty($conf['error_prepend'])) {
-            $this->_error_prepend = $conf['error_prepend'];
-        } else {
-            $this->_error_prepend = ini_get('error_prepend_string');
+        /* Start by configuring the line format. */
+        if (!empty($conf['lineFormat'])) {
+            $this->_lineFormat = str_replace(array_keys($this->_formatMap),
+                                             array_values($this->_formatMap),
+                                             $conf['lineFormat']);
         }
 
-        if (!empty($conf['error_append'])) {
-            $this->_error_append = $conf['error_append'];
+        /* We may need to prepend a string to our line format. */
+        $prepend = null;
+        if (isset($conf['error_prepend'])) {
+            $prepend = $conf['error_prepend'];
         } else {
-            $this->_error_append = ini_get('error_append_string');
+            $prepend = ini_get('error_prepend_string');
         }
+        if (!empty($prepend)) {
+            $this->_lineFormat = $prepend . $this->_lineFormat;
+        }
+
+        /* We may also need to append a string to our line format. */
+        $append = null;
+        if (isset($conf['error_append'])) {
+            $append = $conf['error_append'];
+        } else {
+            $append = ini_get('error_append_string');
+        }
+        if (!empty($append)) {
+            $this->_lineFormat .= $append;
+        }
+
+        /* Lastly, the line ending sequence is also configurable. */
+        if (isset($conf['linebreak'])) {
+            $this->_lineFormat .= $conf['linebreak'];
+        } else {
+            $this->_lineFormat .= "<br />\n";
+        }
+
+        /* The user can also change the time format. */
+        if (!empty($conf['timeFormat'])) {
+            $this->_timeFormat = $conf['timeFormat'];
+        }
+
+        /* Message text conversion can be disabled. */
+        if (isset($conf['rawText'])) {
+            $this->_rawText = $conf['rawText'];
+        }
+    }
+
+    /**
+     * Opens the display handler.
+     *
+     * @access  public
+     * @since   Log 1.9.6
+     */
+    function open()
+    {
+        $this->_opened = true;
+        return true;
+    }
+
+    /**
+     * Closes the display handler.
+     *
+     * @access  public
+     * @since   Log 1.9.6
+     */
+    function close()
+    {
+        $this->_opened = false;
+        return true;
     }
 
     /**
@@ -92,17 +160,22 @@ class Log_display extends Log
         /* Extract the string representation of the message. */
         $message = $this->_extractMessage($message);
 
+        /* Convert the message to an HTML-friendly represention unless raw 
+         * text has been requested. */
+        if ($this->_rawText === false) {
+            $message = nl2br(htmlspecialchars($message));
+        }
+
         /* Build and output the complete log line. */
-        echo $this->_error_prepend .
-             '<b>' . ucfirst($this->priorityToString($priority)) . '</b>: '.
-             nl2br(htmlspecialchars($message)) .
-             $this->_error_append . "<br />\n";
+        echo $this->_format($this->_lineFormat,
+                            strftime($this->_timeFormat),
+                            $priority,
+                            $message);
 
         /* Notify observers about this log message. */
         $this->_announce(array('priority' => $priority, 'message' => $message));
 
         return true;
     }
-}
 
-?>
+}
